@@ -38,14 +38,6 @@ namespace LongoMatch.Interfaces.Multimedia
 			set;
 		}
 
-		bool EnableTitle {
-			set;
-		}
-
-		bool EnableAudio {
-			set;
-		}
-
 		void AddSegment(string filePath, long start, long duration, double rate, string title, bool hasAudio) ;
 		
 		void AddImageSegment(string filePath, long start, long duration, string title) ;
